function [ Kl,Cl,Ml ] = elmt24( local_data )
% elmt24: 2-D three-node (triangular) element for plane strain deformation with 2 dof per node 
% for 2nd order PDE in (x1,x2)
% (Constant strain triangle, etc.)
%
% Element subroutine to construct local stiffness matrix from local data
%
%  local_data.mater = [elt# Modulus Poisson ratio Density prop4 prop5 ] For material type
%
%  local_data.coords = [ x1 x2 of node 1;
%                        x1 x2 of node 2;
%                        x1 x2 of node 3]
%
%  local_data.dofs   = [ dof1 dof2 dof3] Global dof referenced to local dofs
%
  Kl = zeros(6,6);
  Cl = zeros(6,6);
  Ml = zeros(6,6);
  D  = zeros(3,3);
  A  = zeros(3,6);
%
%  Constitutive matrix - Hooke's Law
%
  Emod    = local_data.mater(1,2);
  nu      = local_data.mater(1,3);
  density = local_data.mater(1,4);
%-------------------------------- Evalaute constitutive matrix
  D = Emod/((1+nu)*(1-2*nu)) * [(1-nu)       nu      0;
                                  nu       (1-nu)    0;
                                  0          0     (1-2*nu)/2]
                              
%-------------------------------- Evaluate coefs and determinant for element area
    b = local_data.coords(2,1)*local_data.coords(3,2) - local_data.coords(3,1)*local_data.coords(2,2);
    b21 = local_data.coords(2,2) - local_data.coords(3,2);
    b22 = local_data.coords(3,2) - local_data.coords(1,2); 
    b23 = local_data.coords(1,2) - local_data.coords(2,2);
    b31 = local_data.coords(3,1) - local_data.coords(2,1);
    b32 = local_data.coords(1,1) - local_data.coords(3,1);
    b33 = local_data.coords(2,1) - local_data.coords(1,1);
    d2  = local_data.coords(1,1)*b21 + local_data.coords(1,2)*b31 + b;
    area = d2/2;
%-------------------------------- Evaluate derivatives of shape functions
A = (1/d2) * [ b21   0   b22   0   b23   0;
                0   b31   0   b32   0   b33;
               b31  b21  b32  b22  b33  b23] 
%-------------------------------- Evalaute stiffness matrix
thickness = 1;
Kl = A'*(D*A)*area*thickness
%-------------------------------- Evaluate mass matrix
density = 1;
Ml = density*area*thickness/3 * [1 0 0 0 0 0;
                                 0 1 0 0 0 0; 
                                 0 0 1 0 0 0;
                                 0 0 0 1 0 0;
                                 0 0 0 0 1 0;
                                 0 0 0 0 0 1]

         
         
